LoroException class

Loro异常基类

Implemented types
Implementers

Constructors

LoroException({required String message, int? code, dynamic cause})
创建Loro异常
const

Properties

cause → dynamic
可选的底层错误
final
code int?
可选的错误码
final
hashCode int
The hash code for this object.
no setterinherited
message String
异常消息
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited