LoroSyncException class

同步相关异常

Inheritance

Constructors

LoroSyncException({required String message, int? code, dynamic cause})
创建同步异常
const

Properties

cause → dynamic
可选的底层错误
finalinherited
code int?
可选的错误码
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
异常消息
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited